==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/include/nr.h <==
/*************************************************
* Nyberg-Rueppel Header File                     *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_NYBERG_RUEPPEL_H__
#define OPENCL_NYBERG_RUEPPEL_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>

namespace OpenCL {

/*************************************************
* Nyberg-Rueppel Public Key                      *
*************************************************/
class NR_PublicKey : public PK_Verifying_with_MR_Key
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (q.bits()-1); }

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return p; }
      const BigInt& get_g() const { return g; }
      const BigInt& get_y() const { return y; }

      NR_PublicKey(const BigInt&, const BigInt&, const BigInt&, const BigInt&);
   protected:
      NR_PublicKey() {}
      BigInt p, q, g, y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
      mutable BigInt c, d;
   };

/*************************************************
* Nyberg-Rueppel Private Key                     *
*************************************************/
class NR_PrivateKey : public NR_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_x() const { return x; }

      NR_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                    const BigInt& = 0, const BigInt& = 0);
      NR_PrivateKey(u32bit);
   private:
      BigInt x;
   };

}

#endif

==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/include/nr.h <==
/*************************************************
* Nyberg-Rueppel Header File                     *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_NYBERG_RUEPPEL_H__
#define OPENCL_NYBERG_RUEPPEL_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>
#include <opencl/dl_parm.h>

namespace OpenCL {

/*************************************************
* Nyberg-Rueppel Public Key                      *
*************************************************/
class NR_PublicKey : public PK_Verifying_with_MR_Key
   {
   public:
      SecureVector<byte> verify(const byte[], u32bit) const;

      u32bit max_input_bits() const { return (q.bits()-1); }

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return q; }
      const BigInt& get_g() const { return g; }
      const BigInt& get_y() const { return y; }

      NR_PublicKey(const DL_Group&, const BigInt&);
      NR_PublicKey(const NR_PublicKey&);
   protected:
      DL_Group params;
      const BigInt &p, &q, &g;
      BigInt y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
      mutable BigInt c, d;
   };

/*************************************************
* Nyberg-Rueppel Private Key                     *
*************************************************/
class NR_PrivateKey : public NR_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_x() const { return x; }

      NR_PrivateKey(const DL_Group&);
      NR_PrivateKey(const DL_Group&, const BigInt&, const BigInt&);
   private:
      BigInt x;
   };

}

#endif
